@@ -6,10 +6,11 @@
 
 from PyQt5 import QtCore, QtGui, QtWidgets
 
+
 class Ui_SignalFrame(object):
     def setupUi(self, SignalFrame):
         SignalFrame.setObjectName("SignalFrame")
-        SignalFrame.resize(1057, 539)
+        SignalFrame.resize(1057, 566)
         sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Maximum)
         sizePolicy.setHorizontalStretch(0)
         sizePolicy.setVerticalStretch(0)
@@ -68,6 +69,7 @@ class Ui_SignalFrame(object):
         self.sliderSpectrogramMin.setObjectName("sliderSpectrogramMin")
         self.gridLayout_2.addWidget(self.sliderSpectrogramMin, 19, 1, 1, 1)
         self.spinBoxNoiseTreshold = QtWidgets.QDoubleSpinBox(SignalFrame)
+        self.spinBoxNoiseTreshold.setSuffix("")
         self.spinBoxNoiseTreshold.setDecimals(4)
         self.spinBoxNoiseTreshold.setMaximum(1.0)
         self.spinBoxNoiseTreshold.setSingleStep(0.0001)
@@ -570,7 +572,7 @@ class Ui_SignalFrame(object):
         self.lCenterOffset.setToolTip(_translate("SignalFrame", "<html><head/><body><p>This is the threshold used for determining if a <span style=\" font-weight:600;\">bit is one or zero</span>. You can set it here or grab the middle of the area in <span style=\" font-style:italic;\">Quadrature Demod View.</span></p></body></html>"))
         self.lCenterOffset.setText(_translate("SignalFrame", "Center:"))
         self.spinBoxCenterOffset.setToolTip(_translate("SignalFrame", "<html><head/><body><p>This is the threshold used for determining if a <span style=\" font-weight:600;\">bit is one or zero</span>. You can set it here or grab the middle of the area in <span style=\" font-style:italic;\">Quadrature Demod View</span>.</p></body></html>"))
-        self.cbSignalView.setToolTip(_translate("SignalFrame", "<html><head/><body><p>Choose the view of your signal. Analog, Demodulated or Spectrogram.</p><p>The quadrature demodulation uses a <span style=\" font-weight:600;\">treshold of magnitude,</span> to <span style=\" font-weight:600;\">supress noise</span>. All samples with a magnitude lower than this treshold will be eliminated (set to <span style=\" font-style:italic;\">-127</span>) after demod.</p><p>Tune this value by selecting a <span style=\" font-style:italic;\">noisy area</span> and mark it as noise using <span style=\" font-weight:600;\">context menu</span>.</p><p>Current noise treshold is: </p></body></html>"))
+        self.cbSignalView.setToolTip(_translate("SignalFrame", "<html><head/><body><p>Choose the view of your signal. Analog, Demodulated or Spectrogram.</p><p>The quadrature demodulation uses a <span style=\" font-weight:600;\">threshold of magnitudes,</span> to <span style=\" font-weight:600;\">supress noise</span>. All samples with a magnitude lower than this treshold will be eliminated after demodulation.</p><p>Tune this value by selecting a <span style=\" font-style:italic;\">noisy area</span> and mark it as noise using <span style=\" font-weight:600;\">context menu</span>.</p></body></html>"))
         self.cbSignalView.setItemText(0, _translate("SignalFrame", "Analog"))
         self.cbSignalView.setItemText(1, _translate("SignalFrame", "Demodulated"))
         self.cbSignalView.setItemText(2, _translate("SignalFrame", "Spectrogram"))
@@ -607,6 +609,7 @@ class Ui_SignalFrame(object):
         self.lSamplesTotal.setText(_translate("SignalFrame", "0"))
         self.lSamplesViewText.setText(_translate("SignalFrame", "Samples in view"))
 
+
 from urh.ui.views.EpicGraphicView import EpicGraphicView
 from urh.ui.views.LegendGraphicView import LegendGraphicView
 from urh.ui.views.SpectrogramGraphicView import SpectrogramGraphicView
